import * as i0 from '@angular/core';
import { Directive, Injectable, Inject, EventEmitter, Input, Output, ContentChild, HostListener, NgModule } from '@angular/core';
import { timer, Subject, fromEvent, merge } from 'rxjs';
import { withLatestFrom, filter, mapTo, takeUntil, throttleTime, takeWhile } from 'rxjs/operators';
import { DOCUMENT } from '@angular/common';

class NgsgElementsHelper {
    static findIndex(element) {
        const allElements = element.parentNode.children;
        return Array.prototype.indexOf.call(allElements, element);
    }
}

class NgsgDragHandleDirective {
    constructor(el) {
        this.el = el;
    }
}
/** @nocollapse */ NgsgDragHandleDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: NgsgDragHandleDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
/** @nocollapse */ NgsgDragHandleDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.0", type: NgsgDragHandleDirective, selector: "[ngSortgridDragHandle]", ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: NgsgDragHandleDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngSortgridDragHandle]'
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; } });

class NgsgClassService {
    constructor() {
        this.SELECTED_DEFAULT_CLASS = 'ng-sg-selected';
        this.PLACEHOLDER_DEFAULT_CLASS = 'ng-sg-placeholder';
        this.DROPPED_DEFAULT_CLASS = 'ng-sg-dropped';
        this.ACTIVE_DEFAULT_CLASS = 'ng-sg-active';
    }
    addPlaceHolderClass(element) {
        element.classList.add(this.PLACEHOLDER_DEFAULT_CLASS);
    }
    removePlaceHolderClass(element) {
        element.classList.remove(this.PLACEHOLDER_DEFAULT_CLASS);
    }
    addDroppedClass(element) {
        element.classList.add(this.DROPPED_DEFAULT_CLASS);
    }
    removeDroppedClass(element) {
        element.classList.remove(this.DROPPED_DEFAULT_CLASS);
    }
    addSelectedClass(element) {
        element.classList.add(this.SELECTED_DEFAULT_CLASS);
    }
    removeSelectedClass(element) {
        element.classList.remove(this.SELECTED_DEFAULT_CLASS);
    }
    addActiveClass(element) {
        element.classList.add(this.ACTIVE_DEFAULT_CLASS);
    }
    removeActiveClass(element) {
        element.classList.remove(this.ACTIVE_DEFAULT_CLASS);
    }
}
/** @nocollapse */ NgsgClassService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: NgsgClassService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
/** @nocollapse */ NgsgClassService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: NgsgClassService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: NgsgClassService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

class NgsgStoreService {
    constructor() {
        this.state = new Map();
    }
    initState(group, items = [], classes = {}) {
        this.state.set(group, { items: [...items], classes, selectedItems: [] });
    }
    addSelectedItem(group, dragElement) {
        this.state.get(group).selectedItems.push(dragElement);
    }
    removeSelectedItem(group, item) {
        const updatedItems = this.state.get(group).selectedItems
            .filter((dragElement) => dragElement.node !== item);
        this.setSelectedItems(group, updatedItems);
    }
    setItems(group, items) {
        this.state.get(group).items = [...items];
    }
    getItems(group) {
        return this.state.get(group).items;
    }
    hasItems(group) {
        return this.getItems(group).length > 0;
    }
    hasGroup(group) {
        return this.state.has(group);
    }
    getSelectedItems(group) {
        return this.state.get(group).selectedItems;
    }
    setSelectedItems(group, selectedItems) {
        this.state.get(group).selectedItems = [...selectedItems];
    }
    getFirstSelectItem(group) {
        return this.state.get(group).selectedItems[0];
    }
    hasSelectedItems(group) {
        return this.getSelectedItems(group).length > 0;
    }
    resetSelectedItems(group) {
        this.setSelectedItems(group, []);
    }
    getClasses(group) {
        return this.state.get(group).classes;
    }
}
/** @nocollapse */ NgsgStoreService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: NgsgStoreService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
/** @nocollapse */ NgsgStoreService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: NgsgStoreService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: NgsgStoreService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

class NgsgSortService {
    constructor(classService, ngsgStore) {
        this.classService = classService;
        this.ngsgStore = ngsgStore;
    }
    initSort(group) {
        this.dragIndex = this.ngsgStore.getFirstSelectItem(group).originalIndex;
        this.dragElements = this.ngsgStore.getSelectedItems(group);
    }
    sort(dropElement) {
        const hoverIndex = NgsgElementsHelper.findIndex(dropElement);
        const el = this.getSibling(dropElement, this.dragIndex, hoverIndex);
        if (this.isDropInSelection(el)) {
            return;
        }
        this.dragElements.forEach((dragElement) => {
            const insertedNode = dropElement.parentNode.insertBefore(dragElement.node, el.node);
            this.classService.addPlaceHolderClass(insertedNode);
        });
        this.dragIndex = NgsgElementsHelper.findIndex(this.dragElements[0].node);
    }
    endSort() {
        this.dragElements.forEach((dragElement) => {
            this.updateDropedItem(dragElement.node);
        });
    }
    getSibling(dropElement, dragIndex, hoverIndex) {
        if (dragIndex < hoverIndex) {
            return { node: dropElement.nextSibling, originalIndex: hoverIndex + 1 };
        }
        return { node: dropElement, originalIndex: hoverIndex };
    }
    isDropInSelection(dropElement) {
        return !!this.dragElements.find((dragElment) => dragElment.node === dropElement.node);
    }
    updateDropedItem(item) {
        this.classService.removePlaceHolderClass(item);
        this.classService.addDroppedClass(item);
        this.classService.removeSelectedClass(item);
        this.classService.removeActiveClass(item);
        timer(500).subscribe(() => this.classService.removeDroppedClass(item));
    }
}
/** @nocollapse */ NgsgSortService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: NgsgSortService, deps: [{ token: NgsgClassService }, { token: NgsgStoreService }], target: i0.ɵɵFactoryTarget.Injectable });
/** @nocollapse */ NgsgSortService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: NgsgSortService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: NgsgSortService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: NgsgClassService }, { type: NgsgStoreService }]; } });

var ChangeAction;
(function (ChangeAction) {
    ChangeAction[ChangeAction["ADD"] = 0] = "ADD";
    ChangeAction[ChangeAction["REMOVE"] = 1] = "REMOVE";
})(ChangeAction || (ChangeAction = {}));
class NgsgSelectionService {
    constructor(classService, ngsgStore) {
        this.classService = classService;
        this.ngsgStore = ngsgStore;
        this.COMMAND_KEY = 'Meta';
        this.CONTROL_KEY = 'Control';
        this.selectionChange$ = new Subject();
        const selectionKeyPressed$ = this.selectionKeyPressed();
        this.selectionChange$
            .pipe(withLatestFrom(selectionKeyPressed$))
            .subscribe(([selectionChange, selectionKeyPressed]) => {
            selectionKeyPressed
                ? this.handleSelectionChange(selectionChange)
                : this.resetSelectedItems(selectionChange.key);
        });
    }
    resetSelectedItems(group) {
        this.ngsgStore.getSelectedItems(group).forEach(item => this.classService.removeSelectedClass(item.node));
        this.ngsgStore.resetSelectedItems(group);
    }
    handleSelectionChange(selectionChange) {
        if (selectionChange.action === ChangeAction.ADD) {
            this.classService.addSelectedClass(selectionChange.item);
            this.ngsgStore.addSelectedItem(selectionChange.key, {
                node: selectionChange.item,
                originalIndex: NgsgElementsHelper.findIndex(selectionChange.item)
            });
        }
        if (selectionChange.action === ChangeAction.REMOVE) {
            this.classService.removeSelectedClass(selectionChange.item);
            this.ngsgStore.removeSelectedItem(selectionChange.key, selectionChange.item);
        }
    }
    selectionKeyPressed() {
        const selectionKeyPressed = fromEvent(window, 'keydown').pipe(filter((keyboardEvent) => keyboardEvent.key === this.COMMAND_KEY || keyboardEvent.key === this.CONTROL_KEY), mapTo(true));
        const keyup = fromEvent(window, 'keyup').pipe(mapTo(false));
        return merge(selectionKeyPressed, keyup);
    }
    selectElementIfNoSelection(group, dragedElement) {
        if (this.ngsgStore.hasSelectedItems(group)) {
            return;
        }
        this.ngsgStore.addSelectedItem(group, {
            node: dragedElement,
            originalIndex: NgsgElementsHelper.findIndex(dragedElement)
        });
    }
    updateSelectedDragItem(key, item, selected) {
        this.selectionChange$.next({
            key,
            item,
            action: selected ? ChangeAction.ADD : ChangeAction.REMOVE
        });
    }
}
/** @nocollapse */ NgsgSelectionService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: NgsgSelectionService, deps: [{ token: NgsgClassService }, { token: NgsgStoreService }], target: i0.ɵɵFactoryTarget.Injectable });
/** @nocollapse */ NgsgSelectionService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: NgsgSelectionService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: NgsgSelectionService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: NgsgClassService }, { type: NgsgStoreService }]; } });

class NgsgReflectService {
    constructor(ngsgStore) {
        this.ngsgStore = ngsgStore;
    }
    reflectChanges(key, element) {
        const items = this.ngsgStore.getItems(key);
        const selectedElements = this.ngsgStore.getSelectedItems(key);
        const selectedElementIndices = this.getSelectedElementsIndices(selectedElements);
        const selectedItems = this.getSelectedItems(items, selectedElementIndices);
        const sortedIndices = selectedElementIndices.sort((a, b) => a - b);
        const dropIndex = this.findDropIndex(selectedElements, element);
        while (sortedIndices.length > 0) {
            items.splice(sortedIndices.pop(), 1);
        }
        const result = this.getReflectedItems(items, selectedItems, dropIndex);
        this.ngsgStore.setItems(key, result);
        return result;
    }
    getReflectedItems(items, selectedItems, dropIndex) {
        const beforeSelection = items.slice(0, dropIndex);
        const afterSelection = items.slice(dropIndex, items.length);
        return [...beforeSelection, ...selectedItems, ...afterSelection];
    }
    getSelectedItems(items, selectedElementIndexes) {
        const selectedItems = [];
        selectedElementIndexes.forEach(index => {
            selectedItems.push(items[index]);
        });
        return selectedItems;
    }
    getSelectedElementsIndices(selectedElements) {
        return selectedElements.map((selectedElement) => selectedElement.originalIndex);
    }
    findDropIndex(selectedElements, element) {
        if (this.isDropInSelection(selectedElements, element)) {
            return NgsgElementsHelper.findIndex(selectedElements[0].node);
        }
        return NgsgElementsHelper.findIndex(element);
    }
    isDropInSelection(collection, dropElement) {
        return !!collection.find((dragElment) => dragElment.node === dropElement);
    }
}
/** @nocollapse */ NgsgReflectService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: NgsgReflectService, deps: [{ token: NgsgStoreService }], target: i0.ɵɵFactoryTarget.Injectable });
/** @nocollapse */ NgsgReflectService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: NgsgReflectService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: NgsgReflectService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: NgsgStoreService }]; } });

class NgsgEventsService {
    constructor() {
        this.dropped$ = new Subject();
    }
}
/** @nocollapse */ NgsgEventsService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: NgsgEventsService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
/** @nocollapse */ NgsgEventsService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: NgsgEventsService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: NgsgEventsService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

class ScrollHelperService {
    constructor(document) {
        this.document = document;
        this.DEFAULT_SCROLLSPEED = 50;
        this.SCROLL_BUFFER = 50;
        this.window = document.defaultView;
    }
    scrollIfNecessary(event, scrollPoints = {}, scrollSpeed) {
        const currentPosition = event.pageY - this.window.scrollY;
        if (this.isTopScrollNeeded(currentPosition, scrollPoints.top)) {
            this.window.scrollBy({ top: -scrollSpeed || -this.DEFAULT_SCROLLSPEED, behavior: 'smooth' });
            return;
        }
        if (this.isBottomScrollNeeded(currentPosition, scrollPoints.bottom)) {
            this.window.scrollBy({ top: scrollSpeed || this.DEFAULT_SCROLLSPEED, behavior: 'smooth' });
        }
    }
    isTopScrollNeeded(currentPosition, scrollPointTop) {
        return scrollPointTop ? currentPosition < scrollPointTop :
            currentPosition < this.SCROLL_BUFFER;
    }
    isBottomScrollNeeded(currentPosition, scrollPointBottom) {
        return scrollPointBottom ? currentPosition > scrollPointBottom :
            currentPosition > this.window.innerHeight - this.SCROLL_BUFFER;
    }
}
/** @nocollapse */ ScrollHelperService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: ScrollHelperService, deps: [{ token: DOCUMENT }], target: i0.ɵɵFactoryTarget.Injectable });
/** @nocollapse */ ScrollHelperService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: ScrollHelperService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: ScrollHelperService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () {
        return [{ type: undefined, decorators: [{
                        type: Inject,
                        args: [DOCUMENT]
                    }] }];
    } });

const selector = '[ngSortgridItem]';
class NgsgItemDirective {
    constructor(el, sortService, selectionService, reflectService, ngsgStore, ngsgEventService, scrollHelperService, classService) {
        this.el = el;
        this.sortService = sortService;
        this.selectionService = selectionService;
        this.reflectService = reflectService;
        this.ngsgStore = ngsgStore;
        this.ngsgEventService = ngsgEventService;
        this.scrollHelperService = scrollHelperService;
        this.classService = classService;
        this.ngSortGridGroup = 'defaultGroup';
        this.autoScroll = false;
        this.sorted = new EventEmitter();
        this.selected = false;
        this.destroy$ = new Subject();
    }
    ngOnInit() {
        this.ngsgEventService.dropped$.pipe(takeUntil(this.destroy$)).subscribe(() => this.selected = false);
        fromEvent(this.el.nativeElement, 'drag').pipe(throttleTime(20), takeUntil(this.destroy$), takeWhile(() => this.autoScroll)).subscribe(() => {
            this.scrollHelperService.scrollIfNecessary(event, {
                top: this.scrollPointTop,
                bottom: this.scrollPointBottom
            }, this.scrollSpeed);
        });
    }
    ngOnChanges(changes) {
        const sortGridItemChanges = changes.ngSortGridItems;
        const sortGridItems = sortGridItemChanges.currentValue ? sortGridItemChanges.currentValue : [];
        if (!this.ngsgStore.hasGroup(this.ngSortGridGroup)) {
            this.ngsgStore.initState(this.ngSortGridGroup, sortGridItems);
            return;
        }
        this.ngsgStore.setItems(this.ngSortGridGroup, sortGridItems);
    }
    ngAfterViewInit() {
        var _a, _b;
        this.handleElement = ((_b = (_a = this.handle) === null || _a === void 0 ? void 0 : _a.el) === null || _b === void 0 ? void 0 : _b.nativeElement) || this.el.nativeElement;
        fromEvent(this.handleElement, 'mousedown').pipe(takeUntil(this.destroy$)).subscribe(() => {
            this.el.nativeElement.draggable = true;
        });
    }
    ngOnDestroy() {
        this.destroy$.next(true);
        this.destroy$.complete();
    }
    dragStart(event) {
        if (!this.occuredOnHost(event)) {
            return;
        }
        this.selectionService.selectElementIfNoSelection(this.ngSortGridGroup, event.target);
        this.classService.addActiveClass(event.target);
        this.sortService.initSort(this.ngSortGridGroup);
    }
    dragEnter() {
        if (!this.ngsgStore.hasSelectedItems(this.ngSortGridGroup)) {
            return;
        }
        this.sortService.sort(this.el.nativeElement);
    }
    dragOver(event) {
        if (event.preventDefault) {
            // Necessary. Allows us to drop.
            event.preventDefault();
        }
        return false;
    }
    drop() {
        this.el.nativeElement.draggable = false;
        if (!this.ngsgStore.hasSelectedItems(this.ngSortGridGroup)) {
            return;
        }
        if (!this.ngsgStore.hasItems(this.ngSortGridGroup)) {
            console.warn(`Ng-sortgrid: No items provided - please use [sortGridItems] to pass in an array of items -
      otherwhise the ordered items can not be emitted in the (sorted) event`);
            return;
        }
        const previousOrder = [...this.ngsgStore.getItems(this.ngSortGridGroup)];
        this.sortService.endSort();
        const currentOrder = this.reflectService.reflectChanges(this.ngSortGridGroup, this.el.nativeElement);
        this.sorted.next({ previousOrder, currentOrder });
        this.ngsgStore.resetSelectedItems(this.ngSortGridGroup);
        this.ngsgEventService.dropped$.next(true);
    }
    clicked() {
        this.selected = !this.isItemCurrentlySelected();
        this.selectionService.updateSelectedDragItem(this.ngSortGridGroup, this.el.nativeElement, this.selected);
    }
    isItemCurrentlySelected() {
        const index = NgsgElementsHelper.findIndex(this.el.nativeElement);
        return !!this.ngsgStore.getSelectedItems(this.ngSortGridGroup)
            .find(element => element.originalIndex === index);
    }
    occuredOnHost(event) {
        return event.target.matches(selector);
    }
}
/** @nocollapse */ NgsgItemDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: NgsgItemDirective, deps: [{ token: i0.ElementRef }, { token: NgsgSortService }, { token: NgsgSelectionService }, { token: NgsgReflectService }, { token: NgsgStoreService }, { token: NgsgEventsService }, { token: ScrollHelperService }, { token: NgsgClassService }], target: i0.ɵɵFactoryTarget.Directive });
/** @nocollapse */ NgsgItemDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.0", type: NgsgItemDirective, selector: "[ngSortgridItem]", inputs: { ngSortGridGroup: "ngSortGridGroup", ngSortGridItems: "ngSortGridItems", scrollPointTop: "scrollPointTop", scrollPointBottom: "scrollPointBottom", scrollSpeed: "scrollSpeed", autoScroll: "autoScroll" }, outputs: { sorted: "sorted" }, host: { listeners: { "dragstart": "dragStart($event)", "dragenter": "dragEnter()", "dragover": "dragOver($event)", "dragend": "drop()", "click": "clicked()" } }, queries: [{ propertyName: "handle", first: true, predicate: NgsgDragHandleDirective, descendants: true }], usesOnChanges: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: NgsgItemDirective, decorators: [{
            type: Directive,
            args: [{ selector }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: NgsgSortService }, { type: NgsgSelectionService }, { type: NgsgReflectService }, { type: NgsgStoreService }, { type: NgsgEventsService }, { type: ScrollHelperService }, { type: NgsgClassService }]; }, propDecorators: { ngSortGridGroup: [{
                type: Input
            }], ngSortGridItems: [{
                type: Input
            }], scrollPointTop: [{
                type: Input
            }], scrollPointBottom: [{
                type: Input
            }], scrollSpeed: [{
                type: Input
            }], autoScroll: [{
                type: Input
            }], sorted: [{
                type: Output
            }], handle: [{
                type: ContentChild,
                args: [NgsgDragHandleDirective]
            }], dragStart: [{
                type: HostListener,
                args: ['dragstart', ['$event']]
            }], dragEnter: [{
                type: HostListener,
                args: ['dragenter']
            }], dragOver: [{
                type: HostListener,
                args: ['dragover', ['$event']]
            }], drop: [{
                type: HostListener,
                args: ['dragend']
            }], clicked: [{
                type: HostListener,
                args: ['click']
            }] } });

class NgsgModule {
}
/** @nocollapse */ NgsgModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: NgsgModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
/** @nocollapse */ NgsgModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.0", ngImport: i0, type: NgsgModule, declarations: [NgsgItemDirective, NgsgDragHandleDirective], exports: [NgsgItemDirective, NgsgDragHandleDirective] });
/** @nocollapse */ NgsgModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: NgsgModule });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.0", ngImport: i0, type: NgsgModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [NgsgItemDirective, NgsgDragHandleDirective],
                    exports: [NgsgItemDirective, NgsgDragHandleDirective]
                }]
        }] });

/*
 * Public API Surface of ng-sortgrid
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgsgDragHandleDirective, NgsgItemDirective, NgsgModule };
//# sourceMappingURL=ng-sortgrid.mjs.map
